kvarn::prelude::utils::prelude::compact_str::core::simd::prelude

Trait SimdPartialEq

source
pub trait SimdPartialEq {
    type Mask;

    // Required methods
    fn simd_eq(self, other: Self) -> Self::Mask;
    fn simd_ne(self, other: Self) -> Self::Mask;
}
🔬This is a nightly-only experimental API. (portable_simd)
Parallel PartialEq.

Required Associated Types

source

type Mask

🔬This is a nightly-only experimental API. (portable_simd)

The mask type returned by each comparison.

Required Methods

source

fn simd_eq(self, other: Self) -> Self::Mask

🔬This is a nightly-only experimental API. (portable_simd)

Test if each element is equal to the corresponding element in other.

source

fn simd_ne(self, other: Self) -> Self::Mask

🔬This is a nightly-only experimental API. (portable_simd)

Test if each element is equal to the corresponding element in other.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called